@@ -223,7 +223,9 @@ asCEnum(USER_OBJECT_ s_enum, GType etype)
     gint eval = 0;
 
     if (IS_INTEGER(s_enum) || IS_NUMERIC(s_enum)) {
-        evalue = g_enum_get_value(eclass, asCInteger(s_enum));
+        eval = IS_NUMERIC(s_enum) ? (gint)asCNumeric(s_enum) :
+          asCInteger(s_enum);
+        evalue = g_enum_get_value(eclass, eval);
     } else if (IS_CHARACTER(s_enum)) {
         const gchar* ename = asCString(s_enum);
         evalue = g_enum_get_value_by_name(eclass, ename);
